==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Wylij");
define("_URL","URL");
define("_PRINTER","Strona gotowa do druku");
define("_FRIEND","Wylij ten artyku do znajomych");
define("_YOURNAME","Twoje imi i nazwisko");
define("_OK","Ok!");
define("_RELATED","Pokrewne linki");
define("_MOREABOUT","Wicej o");
define("_NEWSBY","Napisane przez");
define("_MOSTREAD","Najczciej czytany artyku o");
define("_READMORE","Czytaj wicej...");
define("_BYTESMORE","bajtw wicej");
define("_COMMENTSQ","komentarze?");
define("_COMMENT","komentarz");
define("_CONFIGURE","Konfiguracja");
define("_LOGINCREATE","Logowanie/Zaoenie konta");
define("_THRESHOLD","Prg");
define("_NOCOMMENTS","Bez komentarza");
define("_NESTED","Zagniedony");
define("_FLAT","Paski");
define("_THREAD","Wtek");
define("_OLDEST","Starsze jako pierwsze");
define("_NEWEST","Nowsze jako pierwsze");
define("_HIGHEST","Najpierw najwyej oceniane");
define("_COMMENTSWARNING","Komentarze s wasnoci ich twrcw. Nie ponosimy odpowiedzialnoci za ich tre.");
define("_SCORE","Wynik:");
define("_USERINFO","Informacje o uytkowniku");
define("_READREST","Przeczytaj dalszy cig komentarza...");
define("_REPLY","Odpowiedz na to");
define("_REPLYMAIN","Komentarz kocowy");
define("_NOSUBJECT","Bez tematu");
define("_NOANONCOMMENTS","Komentowanie niedozwolone dla anonimowego uytkownika, prosz si <a href=\"modules.php?name=Your_Account&amp;op=new_user\">zarejestrowa</a>");
define("_PARENT","Nadrzdny");
define("_ROOT","Root");
define("_UCOMMENT","Komentarz");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_POSTANON","Wylij anonimowo");
define("_EXTRANS","Zamiana (tagi html na tekst)");
define("_HTMLFORMATED","Formatowanie HTML");
define("_PLAINTEXT","Stary teskst bez formatowania");
define("_ONN","na...");
define("_SUBJECT","Temat");
define("_COMMENTREPLY","Wysanie komentarza");
define("_COMREPLYPRE","Podgld komentarza");
define("_NOTRIGHT","Co jest nie tak ze zmienn w tej funkcji. Ta wiadomo ma wanie ustrzec Ci od bdw");
define("_SENDAMSG","Wylij wiadomo");
define("_YOUSENDSTORY","Wylesz ten artyku");
define("_TOAFRIEND","do wymienionych znajomych:");
define("_FYOURNAME","Twoje imi:");
define("_FYOUREMAIL","Twj email:");
define("_FFRIENDNAME","Imi Twego znajomego:");
define("_FFRIENDEMAIL","Email Twego znajomego:");
define("_INTERESTING","Interesujcy artyku na");
define("_HELLO","Hello");
define("_YOURFRIEND","Twj znajomy");
define("_CONSIDERED","uwaa, e ten artyku jest interesujcy i warty poinformowania Ciebie.");
define("_FDATE","Data:");
define("_FTOPIC","Temat:");
define("_YOUCANREAD","Moesz przeczyta interesujcy artyku na");
define("_FSTORY","Artyku");
define("_HASSENT","Zosta wysany do");
define("_THANKS","Dzikuj!");
define("_RECOMMEND","Zarekomenduj t stron znajomym");
define("_PDATE","Data:");
define("_PTOPIC","Temat:");
define("_COMESFROM","Artyku jest z");
define("_THEURL","Adres tego artykuu to:");
define("_PREVIEW","Podgld");
define("_NEWUSER","Nowy uytkownik");
define("_OPTIONS","Opcje");
define("_REFRESH","Odwie");
define("_ADD","Dodaj");
define("_NOCOMMENTSACT","Przepraszamy, komentarze dla tego artykuu s niedostpne.");
define("_ARTICLEPOLL","Ankieta tego artykuu");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Wylij");
define("_URL","URL");
define("_PRINTER","Strona gotowa do druku");
define("_FRIEND","Wylij ten artyku do znajomych");
define("_YOURNAME","Twoje imi i nazwisko");
define("_OK","Ok!");
define("_RELATED","Pokrewne linki");
define("_MOREABOUT","Wicej o");
define("_NEWSBY","Napisane przez");
define("_MOSTREAD","Najczciej czytany artyku o");
define("_READMORE","Czytaj wicej...");
define("_BYTESMORE","bajtw wicej");
define("_COMMENTSQ","komentarze?");
define("_COMMENT","komentarz");
define("_CONFIGURE","Konfiguracja");
define("_LOGINCREATE","Logowanie/Zaoenie konta");
define("_THRESHOLD","Prg");
define("_NOCOMMENTS","Bez komentarza");
define("_NESTED","Zagniedony");
define("_FLAT","Paski");
define("_THREAD","Wtek");
define("_OLDEST","Starsze jako pierwsze");
define("_NEWEST","Nowsze jako pierwsze");
define("_HIGHEST","Najpierw najwyej oceniane");
define("_COMMENTSWARNING","Komentarze s wasnoci ich twrcw. Nie ponosimy odpowiedzialnoci za ich tre.");
define("_SCORE","Wynik:");
define("_USERINFO","Informacje o uytkowniku");
define("_READREST","Przeczytaj dalszy cig komentarza...");
define("_REPLY","Odpowiedz na to");
define("_REPLYMAIN","Komentarz kocowy");
define("_NOSUBJECT","Bez tematu");
define("_NOANONCOMMENTS","Komentowanie niedozwolone dla anonimowego uytkownika, prosz si <a href=\"modules.php?name=Your_Account&amp;op=new_user\">zarejestrowa</a>");
define("_PARENT","Nadrzdny");
define("_ROOT","Root");
define("_UCOMMENT","Komentarz");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_POSTANON","Wylij anonimowo");
define("_EXTRANS","Zamiana (tagi html na tekst)");
define("_HTMLFORMATED","Formatowanie HTML");
define("_PLAINTEXT","Stary teskst bez formatowania");
define("_ONN","na...");
define("_SUBJECT","Temat");
define("_COMMENTREPLY","Wysanie komentarza");
define("_COMREPLYPRE","Podgld komentarza");
define("_NOTRIGHT","Co jest nie tak ze zmienn w tej funkcji. Ta wiadomo ma wanie ustrzec Ci od bdw");
define("_SENDAMSG","Wylij wiadomo");
define("_YOUSENDSTORY","Wylesz ten artyku");
define("_TOAFRIEND","do wymienionych znajomych:");
define("_FYOURNAME","Twoje imi:");
define("_FYOUREMAIL","Twj email:");
define("_FFRIENDNAME","Imi Twego znajomego:");
define("_FFRIENDEMAIL","Email Twego znajomego:");
define("_INTERESTING","Interesujcy artyku na");
define("_HELLO","Hello");
define("_YOURFRIEND","Twj znajomy");
define("_CONSIDERED","uwaa, e ten artyku jest interesujcy i warty poinformowania Ciebie.");
define("_FDATE","Data:");
define("_FTOPIC","Temat:");
define("_YOUCANREAD","Moesz przeczyta interesujcy artyku na");
define("_FSTORY","Artyku");
define("_HASSENT","Zosta wysany do");
define("_THANKS","Dzikuj!");
define("_RECOMMEND","Zarekomenduj t stron znajomym");
define("_PDATE","Data:");
define("_PTOPIC","Temat:");
define("_COMESFROM","Artyku jest z");
define("_THEURL","Adres tego artykuu to:");
define("_PREVIEW","Podgld");
define("_NEWUSER","Nowy uytkownik");
define("_OPTIONS","Opcje");
define("_REFRESH","Odwie");
define("_ADD","Dodaj");
define("_NOCOMMENTSACT","Przepraszamy, komentarze dla tego artykuu s niedostpne.");
define("_ARTICLEPOLL","Ankieta tego artykuu");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
